#!/usr/bin/env python
# -*- coding: utf-8 -*-

from specparser import get_settings_from_file


def main():
    settings = get_settings_from_file("spec.json")
    print(settings)

    # TODO: Add your code here

    print("Done")

if __name__ == "__main__":
    main()
